@@ -1,14 +1,13 @@
 package Directory::Diff;
 require Exporter;
 @ISA = qw(Exporter);
-@EXPORT_OK = qw/ls_dir get_only get_diff directory_diff
-                default_diff default_dir_only/;
+@EXPORT_OK = qw/ls_dir get_only get_diff directory_diff/;
 %EXPORT_TAGS = (
     all => \@EXPORT_OK,
 );
 use warnings;
 use strict;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 use Carp qw/carp croak/;
 use Cwd 'getcwd';
 use File::Compare 'compare';
@@ -167,17 +166,5 @@ sub directory_diff
     return;
 }
 
-sub default_dir_only
-{
-    my ($data, $dir, $file) = @_;
-    print "File '$file' is only in '$dir'.\n";
-}
-
-sub default_diff
-{
-    my ($data, $dir1, $dir2, $file) = @_;
-    print "File '$file' is different between '$dir1' and '$dir2'.\n";
-}
-
 1;
 
